@@ -21,34 +21,21 @@ QwtPlotItem
 
 import math
 
-from qtpy.QtWidgets import (
-    QWidget,
-    QSizePolicy,
-    QFrame,
-    QApplication,
-)
-from qtpy.QtGui import QFont, QPainter, QPalette, QColor, QBrush
-from qtpy.QtCore import Qt, Signal, QEvent, QSize, QRectF
+import numpy as np
+from qtpy.QtCore import QEvent, QObject, QRectF, QSize, Qt, Signal
+from qtpy.QtGui import QBrush, QColor, QFont, QPainter, QPalette
+from qtpy.QtWidgets import QApplication, QFrame, QSizePolicy, QWidget
 
-from qwt.text import QwtText, QwtTextLabel
-from qwt.scale_widget import QwtScaleWidget
-from qwt.scale_draw import QwtScaleDraw
-from qwt.scale_engine import QwtLinearScaleEngine
+from qwt.graphic import QwtGraphic
+from qwt.interval import QwtInterval
+from qwt.legend import QwtLegendData
 from qwt.plot_canvas import QwtPlotCanvas
 from qwt.scale_div import QwtScaleDiv
+from qwt.scale_draw import QwtScaleDraw
+from qwt.scale_engine import QwtLinearScaleEngine
 from qwt.scale_map import QwtScaleMap
-from qwt.graphic import QwtGraphic
-from qwt.legend import QwtLegendData
-from qwt.interval import QwtInterval
-
-import numpy as np
-
-
-def qwtEnableLegendItems(plot, on):
-    if on:
-        plot.legendDataChanged.connect(plot.updateLegendItems)
-    else:
-        plot.legendDataChanged.disconnect(plot.updateLegendItems)
+from qwt.scale_widget import QwtScaleWidget
+from qwt.text import QwtText, QwtTextLabel
 
 
 def qwtSetTabOrder(first, second, with_children):
@@ -88,111 +75,11 @@ class ItemList(list):
         self.sortItems()
 
 
-class QwtPlotDict_PrivateData(object):
+class QwtPlot_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.itemList = ItemList()
-        self.autoDelete = True
-
-
-class QwtPlotDict(object):
-    """
-    A dictionary for plot items
-
-    `QwtPlotDict` organizes plot items in increasing z-order.
-    If `autoDelete()` is enabled, all attached items will be deleted
-    in the destructor of the dictionary.
-    `QwtPlotDict` can be used to get access to all `QwtPlotItem` items - or
-    all items of a specific type -  that are currently on the plot.
-
-    .. seealso::
-
-        :py:meth:`QwtPlotItem.attach()`, :py:meth:`QwtPlotItem.detach()`,
-        :py:meth:`QwtPlotItem.z()`
-    """
-
-    def __init__(self):
-        self.__data = QwtPlotDict_PrivateData()
-
-    def setAutoDelete(self, autoDelete):
-        """
-        En/Disable Auto deletion
-
-        If Auto deletion is on all attached plot items will be deleted
-        in the destructor of `QwtPlotDict`. The default value is on.
-
-        :param bool autoDelete: enable/disable
-
-        .. seealso::
-
-            :py:meth:`autoDelete()`, :py:meth:`insertItem()`
-        """
-        self.__data.autoDelete = autoDelete
-
-    def autoDelete(self):
-        """
-        :return: true if auto deletion is enabled
-
-        .. seealso::
-
-            :py:meth:`setAutoDelete()`, :py:meth:`insertItem()`
-        """
-        return self.__data.autoDelete
-
-    def insertItem(self, item):
-        """
-        Insert a plot item
-
-        :param qwt.plot.QwtPlotItem item: PlotItem
-
-        .. seealso::
-
-            :py:meth:`removeItem()`
-        """
-        self.__data.itemList.insertItem(item)
-
-    def removeItem(self, item):
-        """
-        Remove a plot item
-
-        :param qwt.plot.QwtPlotItem item: PlotItem
-
-        .. seealso::
-
-            :py:meth:`insertItem()`
-        """
-        self.__data.itemList.removeItem(item)
-
-    def detachItems(self, rtti=None):
-        """
-        Detach items from the dictionary
-
-        :param rtti: In case of `QwtPlotItem.Rtti_PlotItem` or None (default) detach all items otherwise only those items of the type rtti.
-        :type rtti: int or None
-        """
-        for item in self.__data.itemList[:]:
-            if rtti in (None, QwtPlotItem.Rtti_PlotItem) or item.rtti() == rtti:
-                item.attach(None)
-
-    def itemList(self, rtti=None):
-        """
-        A list of attached plot items.
-
-        Use caution when iterating these lists, as removing/detaching an
-        item will invalidate the iterator. Instead you can place pointers
-        to objects to be removed in a removal list, and traverse that list
-        later.
-
-        :param int rtti: In case of `QwtPlotItem.Rtti_PlotItem` detach all items otherwise only those items of the type rtti.
-        :return: List of all attached plot items of a specific type. If rtti is None, return a list of all attached plot items.
-        """
-        if rtti is None or rtti == QwtPlotItem.Rtti_PlotItem:
-            return self.__data.itemList
-        return [item for item in self.__data.itemList if item.rtti() == rtti]
-
-
-class QwtPlot_PrivateData(QwtPlotDict_PrivateData):
-    def __init__(self):
-        super(QwtPlot_PrivateData, self).__init__()
         self.titleLabel = None
         self.footerLabel = None
         self.canvas = None
@@ -215,9 +102,10 @@ class AxisData(object):
         self.scaleDiv = None  # QwtScaleDiv
         self.scaleEngine = None  # QwtScaleEngine
         self.scaleWidget = None  # QwtScaleWidget
+        self.margin = None  # Margin (float) in %
 
 
-class QwtPlot(QFrame, QwtPlotDict):
+class QwtPlot(QFrame):
     """
     A 2-D plotting widget
 
@@ -249,7 +137,7 @@ class QwtPlot(QFrame, QwtPlotDict):
         plot.resize(600, 300)
         plot.show()
 
-    .. image:: /images/QwtPlot_example.png
+    .. image:: /_static/QwtPlot_example.png
 
     .. py:class:: QwtPlot([title=""], [parent=None])
 
@@ -300,7 +188,6 @@ class QwtPlot(QFrame, QwtPlotDict):
                 "%s() takes 0, 1 or 2 argument(s) (%s given)"
                 % (self.__class__.__name__, len(args))
             )
-        QwtPlotDict.__init__(self)
         QFrame.__init__(self, parent)
 
         self.__layout_state = None
@@ -359,18 +246,74 @@ class QwtPlot(QFrame, QwtPlotDict):
         for idx in range(len(focusChain) - 1):
             qwtSetTabOrder(focusChain[idx], focusChain[idx + 1], False)
 
-        qwtEnableLegendItems(self, True)
+        self.legendDataChanged.connect(self.updateLegendItems)
 
-    def __del__(self):
-        self.setAutoReplot(False)
-        # XXX Is is really necessary in Python? (pure transcription of C++)
-        # The following line have been commented to avoid crashing Python
-        # when exiting interpreter (Python 3 only)
+    def insertItem(self, item):
+        """
+        Insert a plot item
 
-    #        self.detachItems(QwtPlotItem.Rtti_PlotItem, self.autoDelete())
-    #        self.__data.layout = None
-    #        self.deleteAxesData()
-    #        self.__data = None
+        :param qwt.plot.QwtPlotItem item: PlotItem
+
+        .. seealso::
+
+            :py:meth:`removeItem()`
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        self.__data.itemList.insertItem(item)
+
+    def removeItem(self, item):
+        """
+        Remove a plot item
+
+        :param qwt.plot.QwtPlotItem item: PlotItem
+
+        .. seealso::
+
+            :py:meth:`insertItem()`
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        self.__data.itemList.removeItem(item)
+
+    def detachItems(self, rtti=None):
+        """
+        Detach items from the dictionary
+
+        :param rtti: In case of `QwtPlotItem.Rtti_PlotItem` or None (default) detach all items otherwise only those items of the type rtti.
+        :type rtti: int or None
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        for item in self.__data.itemList[:]:
+            if rtti in (None, QwtPlotItem.Rtti_PlotItem) or item.rtti() == rtti:
+                item.attach(None)
+
+    def itemList(self, rtti=None):
+        """
+        A list of attached plot items.
+
+        Use caution when iterating these lists, as removing/detaching an
+        item will invalidate the iterator. Instead you can place pointers
+        to objects to be removed in a removal list, and traverse that list
+        later.
+
+        :param int rtti: In case of `QwtPlotItem.Rtti_PlotItem` detach all items otherwise only those items of the type rtti.
+        :return: List of all attached plot items of a specific type. If rtti is None, return a list of all attached plot items.
+
+        .. note::
+
+            This was a member of QwtPlotDict in older versions.
+        """
+        if rtti is None or rtti == QwtPlotItem.Rtti_PlotItem:
+            return self.__data.itemList
+        return [item for item in self.__data.itemList if item.rtti() == rtti]
 
     def setFlatStyle(self, state):
         """
@@ -399,13 +342,9 @@ class QwtPlot(QFrame, QwtPlotDict):
 
         if state:
             # New PythonQwt-exclusive flat style
-            plot_title_font = make_font(
-                family="Helvetica", delta_size=4, weight=QFont.Bold
-            )
-            axis_title_font = make_font(
-                family="Helvetica", delta_size=2, weight=QFont.Bold
-            )
-            axis_label_font = make_font(family="Helvetica", delta_size=0)
+            plot_title_font = make_font(size=12)
+            axis_title_font = make_font(size=11)
+            axis_label_font = make_font(size=10)
             tick_lighter_factors = (150, 125, 100)
             scale_margin = scale_spacing = 0
             canvas_frame_style = QFrame.NoFrame
@@ -490,6 +429,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             d.scaleWidget.setTitle(text)
 
             d.doAutoScale = True
+            d.margin = 0.05
             d.minValue = 0.0
             d.maxValue = 1000.0
             d.stepSize = 0.0
@@ -585,7 +525,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).maxMajor
+            return self.__axisData[axisId].maxMajor
         else:
             return 0
 
@@ -600,7 +540,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).maxMinor
+            return self.__axisData[axisId].maxMinor
         else:
             return 0
 
@@ -641,10 +581,23 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`qwt.scale_engine.QwtScaleEngine.divideScale()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).stepSize
+            return self.__axisData[axisId].stepSize
         else:
             return 0
 
+    def axisMargin(self, axisId):
+        """
+        :param int axisId: Axis index
+        :return: Margin in % of the canvas size
+
+        .. seealso::
+
+            :py:meth:`setAxisMargin()`
+        """
+        if self.axisValid(axisId):
+            return self.__axisData[axisId].margin
+        return 0.0
+
     def axisInterval(self, axisId):
         """
         :param int axisId: Axis index
@@ -658,7 +611,7 @@ class QwtPlot(QFrame, QwtPlotDict):
             :py:meth:`axisScaleDiv()`
         """
         if self.axisValid(axisId):
-            return self.axisWidget(axisId).scaleDiv.interval()
+            return self.axisScaleDiv(axisId).interval()
         else:
             return QwtInterval()
 
@@ -916,6 +869,24 @@ class QwtPlot(QFrame, QwtPlotDict):
                 d.isValid = False
                 self.autoRefresh()
 
+    def setAxisMargin(self, axisId, margin):
+        """
+        Set the margin of the scale widget
+
+        :param int axisId: Axis index
+        :param float margin: Margin in % of the canvas size
+
+        .. seealso::
+
+            :py:meth:`axisMargin()`
+        """
+        if self.axisValid(axisId):
+            d = self.__axisData[axisId]
+            if margin != d.margin:
+                d.margin = margin
+                d.isValid = False
+                self.autoRefresh()
+
     def setAxisTitle(self, axisId, title):
         """
         Change the title of a specified axis
@@ -969,15 +940,20 @@ class QwtPlot(QFrame, QwtPlotDict):
                     intv[item.xAxis()] |= QwtInterval(rect.left(), rect.right())
                 if rect.height() >= 0.0:
                     intv[item.yAxis()] |= QwtInterval(rect.top(), rect.bottom())
+
         for axisId in self.AXES:
             d = self.__axisData[axisId]
             minValue = d.minValue
             maxValue = d.maxValue
             stepSize = d.stepSize
-            if d.doAutoScale and intv[axisId].isValid():
+            if d.margin is not None:
+                intv_i = intv[axisId].extend_fraction(d.margin)
+            else:
+                intv_i = intv[axisId]
+            if d.doAutoScale and intv_i.isValid():
                 d.isValid = False
-                minValue = intv[axisId].minValue()
-                maxValue = intv[axisId].maxValue()
+                minValue = intv_i.minValue()
+                maxValue = intv_i.maxValue()
                 d.scaleEngine.autoScale(d.maxMajor, minValue, maxValue, stepSize)
             if not d.isValid:
                 d.scaleDiv = d.scaleEngine.divideScale(
@@ -991,8 +967,8 @@ class QwtPlot(QFrame, QwtPlotDict):
             # Otherwise, when tick labels are large enough, the ticks
             # may not be aligned with canvas grid.
             # See the following issues for more details:
-            # https://github.com/PierreRaybaut/guiqwt/issues/57
-            # https://github.com/PierreRaybaut/PythonQwt/issues/30
+            # https://github.com/PlotPyStack/guiqwt/issues/57
+            # https://github.com/PlotPyStack/PythonQwt/issues/30
             startDist, endDist = scaleWidget.getBorderDistHint()
             scaleWidget.setBorderDist(startDist, endDist)
 
@@ -1584,9 +1560,9 @@ class QwtPlot(QFrame, QwtPlotDict):
                 if self.__data.legend.parent() is not self:
                     self.__data.legend.setParent(self)
 
-                qwtEnableLegendItems(self, False)
+                self.blockSignals(True)
                 self.updateLegend()
-                qwtEnableLegendItems(self, True)
+                self.blockSignals(False)
 
                 lpos = self.__data.layout.legendPosition()
 
@@ -1697,7 +1673,7 @@ class QwtPlot(QFrame, QwtPlotDict):
         renderer.renderTo(self, printer)
 
     def exportTo(
-        self, filename, size=(800, 600), size_mm=None, resolution=72.0, format_=None
+        self, filename, size=(800, 600), size_mm=None, resolution=85, format_=None
     ):
         """
         Export plot to PDF or image file (SVG, PNG, ...)
@@ -1705,7 +1681,7 @@ class QwtPlot(QFrame, QwtPlotDict):
         :param str filename: Filename
         :param tuple size: (width, height) size in pixels
         :param tuple size_mm: (width, height) size in millimeters
-        :param float resolution: Image resolution
+        :param int resolution: Resolution in dots per Inch (dpi)
         :param str format_: File format (PDF, SVG, PNG, ...)
         """
         if size_mm is None:
@@ -1716,8 +1692,10 @@ class QwtPlot(QFrame, QwtPlotDict):
         renderer.renderDocument(self, filename, size_mm, resolution, format_)
 
 
-class QwtPlotItem_PrivateData(object):
+class QwtPlotItem_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.plot = None
         self.isVisible = True
         self.attributes = 0
