@@ -15,37 +15,27 @@ QwtPlotCanvas
 
 import os
 
+from qtpy.QtCore import QEvent, QObject, QPoint, QPointF, QRect, QRectF, QSize, Qt
+from qtpy.QtGui import (
+    QBrush,
+    QGradient,
+    QImage,
+    QPaintEngine,
+    QPainter,
+    QPainterPath,
+    QPen,
+    QPixmap,
+    QPolygonF,
+    QRegion,
+    qAlpha,
+)
+from qtpy.QtWidgets import QFrame, QStyle, QStyleOption, QStyleOptionFrame
+
 from qwt.null_paintdevice import QwtNullPaintDevice
 from qwt.painter import QwtPainter
 
-from qtpy.QtGui import (
-    QPaintEngine,
-    QPen,
-    QBrush,
-    QRegion,
-    QImage,
-    QPainterPath,
-    QPixmap,
-    QGradient,
-    QPainter,
-    qAlpha,
-    QPolygonF,
-)
-from qtpy.QtWidgets import QFrame, QStyleOption, QStyle
-from qtpy.QtCore import Qt, QSizeF, QEvent, QPointF, QRectF
-from qtpy import QtCore as QC
-
-
-QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
 QT_API = os.environ["QT_API"]
 
-if QT_API in ("pyqt", "pyqt4"):
-    from PyQt4.QtGui import QStyleOptionFrameV3 as QStyleOptionFrame
-elif QT_API == "pyside2":
-    from PySide2.QtWidgets import QStyleOptionFrame
-else:
-    from qtpy.QtWidgets import QStyleOptionFrame
-
 
 class Border(object):
     def __init__(self):
@@ -81,8 +71,17 @@ class QwtStyleSheetRecorder(QwtNullPaintDevice):
             self.__origin = state.brushOrigin()
 
     def drawRects(self, rects, count):
-        for i in range(count):
-            self.border.rectList += [rects[i]]
+        if QT_API.startswith("pyside"):
+            # Pyside
+            if isinstance(rects, (QRect, QRectF)):
+                self.border.list = [rects]
+            else:
+                for i in range(count):
+                    self.border.rectList += [rects.getRect().index(i)]
+        else:
+            # PyQt
+            for i in range(count):
+                self.border.rectList += [rects[i]]
 
     def drawPath(self, path):
         rect = QRectF(QPointF(0.0, 0.0), self.__size)
@@ -281,12 +280,12 @@ def qwtFillBackground(*args):
             r = canvas.rect()
             radius = canvas.borderRadius()
             if radius > 0.0:
-                sz = QSizeF(radius, radius)
+                sz = QSize(radius, radius)
                 rects += [
-                    QRectF(r.topLeft(), sz),
-                    QRectF(r.topRight() - QPointF(radius, 0), sz),
-                    QRectF(r.bottomRight() - QPointF(radius, radius), sz),
-                    QRectF(r.bottomLeft() - QPointF(0, radius), sz),
+                    QRect(r.topLeft(), sz),
+                    QRect(r.topRight() - QPoint(radius, 0), sz),
+                    QRect(r.bottomRight() - QPoint(radius, radius), sz),
+                    QRect(r.bottomLeft() - QPoint(0, radius), sz),
                 ]
 
         qwtFillBackground(painter, canvas, rects)
@@ -301,8 +300,7 @@ def qwtFillBackground(*args):
         else:
             clipRegion = widget.contentsRect()
         bgWidget = qwtBackgroundWidget(widget.parentWidget())
-        for fillRect in fillRects:
-            rect = QRectF(fillRect).toAlignedRect()
+        for rect in fillRects:
             if clipRegion.intersects(rect):
                 pm = QPixmap(rect.size())
                 QwtPainter.fillPixmap(
@@ -331,8 +329,10 @@ class StyleSheet(object):
         self.background = StyleSheetBackground()
 
 
-class QwtPlotCanvas_PrivateData(object):
+class QwtPlotCanvas_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.focusIndicator = QwtPlotCanvas.NoFocusIndicator
         self.borderRadius = 0
         self.paintAttributes = 0
@@ -491,10 +491,7 @@ class QwtPlotCanvas(QFrame):
                 if self.__data.backingStore is None:
                     self.__data.backingStore = QPixmap()
                 if self.isVisible():
-                    if QT_MAJOR_VERSION >= 5:
-                        self.__data.backingStore = self.grab(self.rect())
-                    else:
-                        self.__data.backingStore = QPixmap.grabWidget(self, self.rect())
+                    self.__data.backingStore = self.grab(self.rect())
             else:
                 self.__data.backingStore = None
         elif attribute == self.Opaque:
@@ -591,12 +588,10 @@ class QwtPlotCanvas(QFrame):
         if (
             self.testPaintAttribute(self.BackingStore)
             and self.__data.backingStore is not None
+            and not self.__data.backingStore.isNull()
         ):
             bs = self.__data.backingStore
-            if QT_MAJOR_VERSION >= 5:
-                pixelRatio = bs.devicePixelRatio()
-            else:
-                pixelRatio = 1.0
+            pixelRatio = bs.devicePixelRatio()
             if bs.size() != self.size() * pixelRatio:
                 bs = QwtPainter.backingStore(self, self.size())
                 if self.testAttribute(Qt.WA_StyledBackground):
@@ -756,9 +751,9 @@ class QwtPlotCanvas(QFrame):
                 opt.midLineWidth = self.midLineWidth()
             else:
                 opt.lineWidth = self.frameWidth()
-            if frameShadow == self.Sunken:
+            if frameShadow == QFrame.Sunken:
                 opt.state |= QStyle.State_Sunken
-            elif frameShadow == self.Raised:
+            elif frameShadow == QFrame.Raised:
                 opt.state |= QStyle.State_Raised
             self.style().drawControl(QStyle.CE_ShapedFrame, opt, painter, self)
 
