@@ -15,7 +15,17 @@ QwtSymbol
 
 import math
 
-from qtpy.QtCore import QLineF, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, Qt
+from qtpy.QtCore import (
+    QLineF,
+    QObject,
+    QPoint,
+    QPointF,
+    QRect,
+    QRectF,
+    QSize,
+    QSizeF,
+    Qt,
+)
 from qtpy.QtGui import (
     QBrush,
     QPainter,
@@ -334,14 +344,15 @@ def qwtDrawHexagonSymbols(painter, points, symbol):
         painter.drawPolygon(QPolygonF(hexa))
 
 
-class QwtSymbol_PrivateData(object):
+class QwtSymbol_PrivateData(QObject):
     def __init__(self, st, br, pn, sz):
+        QObject.__init__(self)
         self.style = st
         self.size = sz
         self.brush = br
         self.pen = pn
         self.isPinPointEnabled = False
-        self.pinPoint = QPointF()
+        self.pinPoint = None
 
         class Path(object):
             def __init__(self):
@@ -1235,7 +1246,7 @@ class QwtSymbol(object):
             :py:meth:`setCachePolicy()`, :py:meth:`drawSymbols()`
         """
         if self.__data.cache.pixmap is not None:
-            self.__data.cache.pixmap = QPixmap()
+            self.__data.cache.pixmap = None
 
     def setStyle(self, style):
         """
