@@ -47,22 +47,22 @@ import math
 import os
 import struct
 
+from qtpy.QtCore import QObject, QRectF, QSize, QSizeF, Qt
 from qtpy.QtGui import (
+    QAbstractTextDocumentLayout,
+    QColor,
+    QFont,
+    QFontInfo,
+    QFontMetrics,
+    QFontMetricsF,
     QPainter,
     QPalette,
-    QFont,
-    QFontMetrics,
-    QColor,
+    QPixmap,
     QTextDocument,
     QTextOption,
-    QFontMetricsF,
-    QPixmap,
-    QFontInfo,
     QTransform,
-    QAbstractTextDocumentLayout,
 )
-from qtpy.QtWidgets import QFrame, QWidget, QSizePolicy, QApplication
-from qtpy.QtCore import Qt, QSizeF, QSize, QRectF
+from qtpy.QtWidgets import QApplication, QFrame, QSizePolicy, QWidget
 
 from qwt.painter import QwtPainter
 from qwt.qthelpers import qcolor_from_str
@@ -120,9 +120,6 @@ class QwtTextEngine(object):
 
     `QwtPlainTextEngine` and `QwtRichTextEngine` are part of the
     `PythonQwt` library.
-    The implementation of `QwtMathMLTextEngine` uses code from the
-    `Qt` solution package. Because of license implications it is built into
-    a separate library.
 
     .. seealso::
 
@@ -209,7 +206,10 @@ def qwtUnscaleFont(painter):
     dpix, dpiy = get_screen_resolution()
     pd = painter.device()
     if pd.logicalDpiX() != dpix or pd.logicalDpiY() != dpiy:
-        pixelFont = QFont(painter.font(), QApplication.desktop())
+        try:
+            pixelFont = QFont(painter.font(), QApplication.desktop())
+        except AttributeError:
+            pixelFont = QFont(painter.font())
         pixelFont.setPixelSize(QFontInfo(pixelFont).pixelSize())
         painter.setFont(pixelFont)
 
@@ -457,8 +457,10 @@ class QwtRichTextEngine(QwtTextEngine):
         return 0, 0, 0, 0
 
 
-class QwtText_PrivateData(object):
+class QwtText_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.renderFlags = Qt.AlignCenter
         self.borderRadius = 0
         self.borderPen = Qt.NoPen
@@ -474,11 +476,11 @@ class QwtText_PrivateData(object):
 
 class QwtText_LayoutCache(object):
     def __init__(self):
-        self.textSize = QSizeF()
+        self.textSize = None
         self.font = None
 
     def invalidate(self):
-        self.textSize = QSizeF()
+        self.textSize = None
 
 
 class QwtText(object):
@@ -535,21 +537,6 @@ class QwtText(object):
 
         Use the Scribe framework (Qt Rich Text) to render the text.
 
-      * `QwtText.MathMLText`:
-
-        Use a MathML (http://en.wikipedia.org/wiki/MathML) render engine
-        to display the text. The Qwt MathML extension offers such an engine
-        based on the MathML renderer of the Qt solutions package.
-        To enable MathML support the following code needs to be added to the
-        application::
-
-            QwtText.setTextEngine(QwtText.MathMLText, QwtMathMLTextEngine())
-
-      * `QwtText.TeXText`:
-
-        Use a TeX (http://en.wikipedia.org/wiki/TeX) render engine
-        to display the text ( not implemented yet ).
-
       * `QwtText.OtherFormat`:
 
         The number of text formats can be extended using `setTextEngine`.
@@ -578,7 +565,7 @@ class QwtText(object):
     """
 
     # enum TextFormat
-    AutoText, PlainText, RichText, MathMLText, TeXText = list(range(5))
+    AutoText, PlainText, RichText = list(range(3))
     OtherFormat = 100
 
     # enum PaintAttribute
@@ -1002,7 +989,8 @@ class QwtText(object):
         """
         font = QFont(self.usedFont(defaultFont))
         if (
-            not self.__layoutCache.textSize.isValid()
+            self.__layoutCache.textSize is None
+            or not self.__layoutCache.textSize.isValid()
             or self.__layoutCache.font is not font
         ):
             self.__layoutCache.textSize = self.__data.textEngine.textSize(
@@ -1118,8 +1106,10 @@ class QwtText(object):
         self.__map.setdefault(format_, engine)
 
 
-class QwtTextLabel_PrivateData(object):
+class QwtTextLabel_PrivateData(QObject):
     def __init__(self):
+        QObject.__init__(self)
+
         self.indent = 4
         self.margin = 0
         self.text = QwtText()
